==> tikiwiki-9.2.tbz: www/tikiwiki-9.2/lang/en/language.php <==
<?php


$lang = array(
"faq" => "FAQ",
"Allows to select an image as an icon attached to the tracker item from file galleries" => "Provides ability to select an image as an icon attached to the tracker item from file galleries",
"Allows to select a geolocation for the item and displays it on a map" => "Allow a geolocation to be selected for the item and displays it on a map",
"Allows to create arbitrary relations between the trackers and other objects in the system" => "Allows arbitrary relations to be created between the trackers and other objects in the system",
"Allows to input an email address with options of making it active" => "Allows an email address to be input with options of making it active",
"E-mail attribute" => "Email attribute",
"By default, all languages supported by tikiwiki are available on multilingual sites. This option allows to limit the languages to a subset" => "By default, all languages supported by tikiwiki are available on multilingual sites. This option allows languages to be limited to a subset",
"Allows to set tags on pages and various objects within the website and generate tag cloud navigation patterns" => "Allows tags on pages and various objects to be set within the website and generate tag cloud navigation patterns",
"Allows to keep track of what users are doing and produce reports on a per-user or per-category basis" => "Provides ability to track what users are doing and produce reports on a per-user or per-category basis",
"Add a \"Share\" link in all pages to send it via e-mail, Twitter, Facebook, message or forums" => "Add a \"Share\" link in all pages to send it via email, Twitter, Facebook, message or forums",
"Allows to control the menu options that can be seen by a user" => "Allows the menu options that can be seen by a user to be controlled",
"Going beyond Backlinks, allows to define some semantic relationships between wiki pages" => "Going beyond Backlinks, allows some semantic relationships to be defined between wiki pages",
"Search engine friendly url Postfilter" => "Search engine friendly URL Postfilter",
"Display article title in the sefurl" => "Display article title in the SEFURL",
"Using custom blog headings will use significantly more server resources. Unless you need per-blog templates, you should use a customize the template file" => "Using custom blog headings will use significantly more server resources. Unless you need per-blog templates, you should customize the template file instead.",
"E-mail" => "Email",
"Html Feed" => "HTML Feed",
"A way to push and pull html bits around from one site to another" => "A way to push and pull HTML bits around from one site to another",
"Propose basic http authentication if the user has no permission to see the feed" => "Propose basic HTTP authentication if the user has no permission to see the feed",
"Minimum amount of seconds to be ellapsed between source checks to prevent flooding servers" => "Minimum amount of seconds to be elapsed between source checks to prevent flooding servers",
"Allows to define icons for menu entries" => "Allows icons to be defined for menu entries",
"Allows to map domain names to perspectives and simulate multiple domains hosted on the same instance" => "Allows domain names to be mapped to perspectives and simulate multiple domains hosted on the same instance",
"Each registry in Cclite can have it's own currency. Must be one per registry. (case sensitive)" => "Each registry in Cclite can have its own currency. Must be one per registry. (case sensitive)",
"Allows to direct users to a specific perspective depending on the origin IP address. Can be used inside intranets to use different configurations for users depending on their departements or discriminate people in web contexts. Unspecified IPs will fall back to default behavior, including multi-domain handling. Manually selected perspectives take precedence over this" => "Allows users to be directed to a specific perspective depending on the origin IP address. Can be used inside intranets to use different configurations for users depending on their departements or discriminate people in web contexts. Unspecified IPs will fall back to default behavior, including multi-domain handling. Manually selected perspectives take precedence over this",
"Allows to clone a tracker on a remote host and synchronize the data locally on demand" => "Allows a tracker to be cloned on a remote host and synchronize the data locally on demand",
"Allows to set the field weights that apply when ranking the pages for search listing. The weight only applies when the field is in the query. To nullify the value of a field, use an insignificant amount, not 0, which may lead to unexpected behaviors, such as stripping results" => "Allows the field weights to be set that apply when ranking the pages for search listing. The weight only applies when the field is in the query. To nullify the value of a field, use an insignificant amount, not 0, which may lead to unexpected behaviors, such as stripping results",
"All of the content is aggregated in the contents field. For custom weighting to apply, the fields must be included in the query. This option allows to include other fields in the default content search" => "All of the content is aggregated in the contents field. For custom weighting to apply, the fields must be included in the query. This option allows other fields to be included in the default content search",
"Include a flag by each e-mail to quickly flag/un-flag them" => "Include a flag by each email to quickly flag/un-flag them",
"Allows to modify the style in which the author list is displayed on a per-page basis" => "Allows the style in which the author list is displayed to be modified on a per-page basis",
"Alert by e-mail users with permission to approve plugin when a plugin is pending approval" => "Alert by email users with permission to approve plugin when a plugin is pending approval",
"This allows a mixture of wiki and HTML. All wiki syntax is parsed" => "This allows a mixture of wiki and HTML. All wiki syntax is parsed",
"This also allows a mixture of wiki and HTML. Only some wiki syntax is parsed, such as plugins (not inline character styles etc)" => "This also allows a mixture of wiki and HTML. Only some wiki syntax is parsed, such as plugins (not inline character styles etc)",
"Some of your preferences should be set differently for this to work at it's best. Please click this to apply the recommended profile" => "Some of your preferences should be set differently for this to work at its best. Please click this to apply the recommended profile",
"faqs" => "FAQs",
"Can admin faqs" => "Can admin FAQs",
"Can suggest faq questions" => "Can suggest FAQ questions",
"Can view faqs" => "Can view FAQs",
"Can subscribe many e-mails at once (requires tiki_p_subscribe email)" => "Can subscribe many emails at once (requires tiki_p_subscribe email)",
"Creates exercises within a wiki page for students to test their new skills. The plugin allows to define inline questions and optional answers to be selected from. A score is given for multiple exercises within a page" => "Creates exercises within a wiki page for students to test their new skills. Inline questions and optional answers selections can be defined. A score is given for multiple exercises within a page",
"Adds an item to HTML feed" => "Adds an item to HTML feed",
"HTML Feed Link" => "HTML Feed Link",
"Is the HTML feed moderated" => "Is the HTML feed moderated",
"Date of last accepted HTML item, not used if not moderated" => "Date of last accepted HTML item, not used if not moderated",
"Any HTML color" => "Any HTML color",
"Allows to toggle from tabs to no tabs view" => "Allow toggling from tabs to no tabs view",
"Text or HTML setting" => "Text or HTML setting",
"Fields marked with a * are mandatory" => "Fields marked with an * are mandatory",
"Displays the content of the cart, allows to modify quantities and proceed to payment" => "Displays the content of the cart, allows quantities to be modified and proceeds to payment",
"Faq identifier" => "FAQ identifier",
"If set to a faq identifier, restricts the chosen questions to those in the identified faq" => "If set to a FAQ identifier, restricts the chosen questions to those in the identified FAQ",
"Allows to draw shapes over the map" => "Allows shapes to be drawn over the map",
"The shoutbox is a quick messaging tool. Messages reload each time the page changes. Anyone with the right permission can see all messages. Another permission allows to send messages" => "The shoutbox is a quick messaging tool. Messages reload each time the page changes. Anyone with the right permission can see all messages. Another permission allows messages to be sent.",
"Allows to open a dialog to create new tracker items" => "Allows a dialog to be opened to create new tracker items",
"Copyright allows to determine a copyright for all the objects of tiki" => "Copyright allows a copyright to be determined for all the objects of tiki",
"If you would like to be notified when someone replies to this topic<br />please tell us your e-mail address" => "If you would like to be notified when someone replies to this topic<br />please tell us your email address",
"Send me an e-mail when someone replies" => "Send me an email when someone replies",
"Allows to select each user for small groups" => "Allows each user to be selected for small groups",
"Your database requires an update to match the current Tiki version. Please proceed to <a href=\"tiki-install.php\">the installer</a>. Using Tiki with an incorrect database version usually provokes errors" => "Your database requires an update to match the the Tiki version; use <a href=\"tiki-install.php\">the installer</a>. Using Tiki with an incorrect database version will cause errors",
"Is HTML" => "Is HTML",
"Forward messages to this forum to this e-mail address, in a format that can be used for sending back to the inbound forum e-mail address" => "Forward messages to this forum to this email address, in a format that can be used for sending back to the inbound forum email address",
"Originating e-mail address for mails from this forum" => "Originating email address for mails from this forum",
"txt file, one e-mail per line" => "txt file, one email per line",
"Wiki page, one e-mail per line" => "Wiki page, one email per line",
"Emails on a wiki page which will be added at each newsletter sending, one e-mail per line" => "Emails on a wiki page which will be added at each newsletter sending, one email per line",
"Allow customized text message to be sent with the HTML version" => "Allow customized text message to be sent with the HTML version",
"Jan" => "Jan.",
"Feb" => "Feb.",
"Mar" => "Mar.",
"Apr" => "Apr.",
"Jun" => "June",
"Jul" => "July",
"Aug" => "Aug.",
"Sep" => "Sep.",
"Oct" => "Oct.",
"Nov" => "Nov.",
"Update every unchanged events of this recurrence rule" => "Update every unchanged event in this recurrence series",
"Update every events of this recurrence rule" => "Update every event in this recurrence series",
"Delete Recurrent events" => "Delete recurrent events",
"numeric between ~ for HTML numeric characters entity" => "numeric between ~ for HTML numeric characters entity",
"If your pages contain XML code, the HTML purifier will delete it. Deactivate this feature" => "If your pages contain XML code, the HTML purifier will delete it. Deactivate this feature",
"Fill this box with the list of e-mails you want to invite " => "Fill this box with the list of emails you want to invite ",
"Type here the e-mail subject you'll want to be sent to them " => "Type here the email subject you'll want to be sent to them ",
"Type here the e-mail content you'll want to be sent to them (and let the {literal}{link}{/literal} word, it will be replaced with the good link for registering) " => "Type here the email content you'll want to be sent to them (and let the {literal}{link}{/literal} word, it will be replaced with the good link for registering) ",
"The link was sent via e-Mail to the following addresses" => "The link was sent via email to the following addresses",
"e-Mail" => "email",
"Send via e-Mail" => "Send via email",
"Unavailable - please set your e-mail below" => "Unavailable - please set your email below",
"Send me an e-mail when someone replies to my topic" => "Send me an email when someone replies to my topic",
"Don't send me any e-mails" => "Don't send me any emails",
"Personal e-mail accounts" => "Personal email accounts",
"Group e-mail accounts" => "Group email accounts",
"Use simplified e-mail format" => "Use simplified email format",
"The \"Regex Wikiplugin\" is activated. It can be used by wiki editors to create any html via regex replacement" => "The \"Regex Wikiplugin\" is activated. It can be used by wiki editors to create any HTML via regex replacement",
"You must make sure to have a valid e-mail address in the From field" => "You must make sure to have a valid email address in the From field",
"No faq indicated" => "No FAQ indicated",
);

==> tikiwiki-11.0.tbz: www/tikiwiki-11.0/lang/en/language.php <==
<?php


$lang = array(
"faq" => "FAQ",
"Allows to select an image as an icon attached to the tracker item from file galleries" => "Provides ability to select an image as an icon attached to the tracker item from file galleries",
"Allows to select a geolocation for the item and displays it on a map" => "Allow a geolocation to be selected for the item and displays it on a map",
"Allows to create arbitrary relations between the trackers and other objects in the system" => "Allows arbitrary relations to be created between the trackers and other objects in the system",
"Allows to input an email address with options of making it active" => "Allows an email address to be input with options of making it active",
"E-mail attribute" => "Email attribute",
"Allows to set tags on pages and various objects within the website and generate tag cloud navigation patterns" => "Allows tags on pages and various objects to be set within the website and generate tag cloud navigation patterns",
"Allows to keep track of what users are doing and produce reports on a per-user or per-category basis" => "Provides ability to track what users are doing and produce reports on a per-user or per-category basis",
"Add a \"Share\" link in all pages to send it via e-mail, Twitter, Facebook, message or forums" => "Add a \"Share\" link in all pages to send it via email, Twitter, Facebook, message or forums",
"Allows to control the menu options that can be seen by a user" => "Allows the menu options that can be seen by a user to be controlled",
"Going beyond Backlinks, allows to define some semantic relationships between wiki pages" => "Going beyond Backlinks, allows some semantic relationships to be defined between wiki pages",
"Search engine friendly URL Postfilter" => "Search engine friendly URL Postfilter",
"Display article title in the sefurl" => "Display article title in the SEFURL",
"Using custom blog headings will use significantly more server resources. Unless you need per-blog templates, you should use a customize the template file" => "Using custom blog headings will use significantly more server resources. Unless you need per-blog templates, you should customize the template file instead.",
"E-mail" => "Email",
"Html Feed" => "HTML Feed",
"A way to push and pull html bits around from one site to another" => "A way to push and pull HTML bits around from one site to another",
"Propose basic http authentication if the user has no permission to see the feed" => "Propose basic HTTP authentication if the user has no permission to see the feed",
"Minimum amount of seconds to be ellapsed between source checks to prevent flooding servers" => "Minimum amount of seconds to be elapsed between source checks to prevent flooding servers",
"Allows to define icons for menu entries" => "Allows icons to be defined for menu entries",
"Allows to map domain names to perspectives and simulate multiple domains hosted on the same instance" => "Allows domain names to be mapped to perspectives and simulate multiple domains hosted on the same instance",
"Each registry in Cclite can have it's own currency. Must be one per registry. (case sensitive)" => "Each registry in Cclite can have its own currency. Must be one per registry. (case sensitive)",
"Allows to direct users to a specific perspective depending on the origin IP address. Can be used inside intranets to use different configurations for users depending on their departements or discriminate people in web contexts. Unspecified IPs will fall back to default behavior, including multi-domain handling. Manually selected perspectives take precedence over this" => "Allows users to be directed to a specific perspective depending on the origin IP address. Can be used inside intranets to use different configurations for users depending on their departements or discriminate people in web contexts. Unspecified IPs will fall back to default behavior, including multi-domain handling. Manually selected perspectives take precedence over this",
"Allows to clone a tracker on a remote host and synchronize the data locally on demand" => "Allows a tracker to be cloned on a remote host and synchronize the data locally on demand",
"Allows to set the field weights that apply when ranking the pages for search listing. The weight only applies when the field is in the query. To nullify the value of a field, use an insignificant amount, not 0, which may lead to unexpected behaviors, such as stripping results" => "Allows the field weights to be set that apply when ranking the pages for search listing. The weight only applies when the field is in the query. To nullify the value of a field, use an insignificant amount, not 0, which may lead to unexpected behaviors, such as stripping results",
"All of the content is aggregated in the contents field. For custom weighting to apply, the fields must be included in the query. This option allows to include other fields in the default content search" => "All of the content is aggregated in the contents field. For custom weighting to apply, the fields must be included in the query. This option allows other fields to be included in the default content search",
"Include a flag by each e-mail to quickly flag/un-flag them" => "Include a flag by each email to quickly flag/un-flag them",
"Allows to modify the style in which the author list is displayed on a per-page basis" => "Allows the style in which the author list is displayed to be modified on a per-page basis",
"Alert by e-mail users with permission to approve plugin when a plugin is pending approval" => "Alert by email users with permission to approve plugin when a plugin is pending approval",
"This allows a mixture of wiki and HTML. All wiki syntax is parsed" => "This allows a mixture of wiki and HTML. All wiki syntax is parsed",
"This also allows a mixture of wiki and HTML. Only some wiki syntax is parsed, such as plugins (not inline character styles etc)" => "This also allows a mixture of wiki and HTML. Only some wiki syntax is parsed, such as plugins (not inline character styles etc)",
"faqs" => "FAQs",
"Can admin faqs" => "Can admin FAQs",
"Can suggest faq questions" => "Can suggest FAQ questions",
"Can view faqs" => "Can view FAQs",
"Can subscribe many e-mails at once (requires tiki_p_subscribe email)" => "Can subscribe many emails at once (requires tiki_p_subscribe email)",
"Creates exercises within a wiki page for students to test their new skills. The plugin allows to define inline questions and optional answers to be selected from. A score is given for multiple exercises within a page" => "Creates exercises within a wiki page for students to test their new skills. Inline questions and optional answers selections can be defined. A score is given for multiple exercises within a page",
"HTML Feed Link" => "HTML Feed Link",
"Date of last accepted HTML item, not used if not moderated" => "Date of last accepted HTML item, not used if not moderated",
"Format: x,y,zoom where x is the longitude, and y is the latitude. Zoom is between 0(view Earth) and 19" => "Format: x,y,zoom where x is the longitude, and y is the latitude. Zoom is between 0 (view Earth) and 19",
"Any HTML color" => "Any HTML color",
"Allows to toggle from tabs to no tabs view" => "Allow toggling from tabs to no tabs view",
"Text or HTML setting" => "Text or HTML setting",
"Fields marked with a * are mandatory" => "Fields marked with an * are mandatory",
"Displays the content of the cart, allows to modify quantities and proceed to payment" => "Displays the content of the cart, allows quantities to be modified and proceeds to payment",
"Faq identifier" => "FAQ identifier",
"If set to a faq identifier, restricts the chosen questions to those in the identified faq" => "If set to a FAQ identifier, restricts the chosen questions to those in the identified FAQ",
"Allows to draw shapes over the map" => "Allows shapes to be drawn over the map",
"The shoutbox is a quick messaging tool. Messages reload each time the page changes. Anyone with the right permission can see all messages. Another permission allows to send messages" => "The shoutbox is a quick messaging tool. Messages reload each time the page changes. Anyone with the right permission can see all messages. Another permission allows messages to be sent.",
"Allows to open a dialog to create new tracker items" => "Allows a dialog to be opened to create new tracker items",
"Copyright allows to determine a copyright for all the objects of tiki" => "Copyright allows a copyright to be determined for all the objects of tiki",
"Click Here to Insert in Wiki Syntax" => "Click here to use the file",
"Send me an e-mail when someone replies" => "Send me an email when someone replies",
"Allows to select each user for small groups" => "Allows each user to be selected for small groups",
"Your database requires an update to match the current Tiki version. Please proceed to <a href=\"tiki-install.php\">the installer</a>. Using Tiki with an incorrect database version usually provokes errors" => "Your database requires an update to match the the Tiki version; use <a href=\"tiki-install.php\">the installer</a>. Using Tiki with an incorrect database version will cause errors",
"Is HTML" => "Is HTML",
"Forward messages to this forum to this e-mail address, in a format that can be used for sending back to the inbound forum e-mail address" => "Forward messages to this forum to this email address, in a format that can be used for sending back to the inbound forum email address",
"Originating e-mail address for mails from this forum" => "Originating email address for mails from this forum",
"txt file, one e-mail per line" => "txt file, one email per line",
"Wiki page, one e-mail per line" => "Wiki page, one email per line",
"Emails on a wiki page which will be added at each newsletter sending, one e-mail per line" => "Emails on a wiki page which will be added at each newsletter sending, one email per line",
"Allow customized text message to be sent with the HTML version" => "Allow customized text message to be sent with the HTML version",
"Jan" => "Jan.",
"Feb" => "Feb.",
"Mar" => "Mar.",
"Apr" => "Apr.",
"Jun" => "June",
"Jul" => "July",
"Aug" => "Aug.",
"Sep" => "Sep.",
"Oct" => "Oct.",
"Nov" => "Nov.",
"Update every unchanged events of this recurrence rule" => "Update every unchanged event in this recurrence series",
"Update every events of this recurrence rule" => "Update every event in this recurrence series",
"Delete Recurrent events" => "Delete recurrent events",
"numeric between ~ for HTML numeric characters entity" => "numeric between ~ for HTML numeric characters entity",
"If your pages contain XML code, the HTML purifier will delete it. Deactivate this feature" => "If your pages contain XML code, the HTML purifier will delete it. Deactivate this feature",
"Fill this box with the list of e-mails you want to invite " => "Fill this box with the list of emails you want to invite ",
"Type here the e-mail subject you'll want to be sent to them " => "Type here the email subject you'll want to be sent to them ",
"Type here the e-mail content you'll want to be sent to them (and let the {literal}{link}{/literal} word, it will be replaced with the good link for registering) " => "Type here the email content you'll want to be sent to them (and let the {literal}{link}{/literal} word, it will be replaced with the good link for registering) ",
"The link was sent via e-Mail to the following addresses" => "The link was sent via email to the following addresses",
"e-Mail" => "email",
"Send via e-Mail" => "Send via email",
"Unavailable - please set your e-mail below" => "Unavailable - please set your email below",
"Send me an e-mail when someone replies to my topic" => "Send me an email when someone replies to my topic",
"Don't send me any e-mails" => "Don't send me any emails",
"Personal e-mail accounts" => "Personal email accounts",
"Group e-mail accounts" => "Group email accounts",
"Use simplified e-mail format" => "Use simplified email format",
"The \"Regex Wikiplugin\" is activated. It can be used by wiki editors to create any html via regex replacement" => "The \"Regex Wikiplugin\" is activated. It can be used by wiki editors to create any HTML via regex replacement",
"You must make sure to have a valid e-mail address in the From field" => "You must make sure to have a valid email address in the From field",
"No faq indicated" => "No FAQ indicated",
);
